#[non_exhaustive]pub struct GetPreparedStatementInput {
pub statement_name: Option<String>,
pub work_group: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.statement_name: Option<String>The name of the prepared statement to retrieve.
work_group: Option<String>The workgroup to which the statement to be retrieved belongs.
Implementations
Sourceimpl GetPreparedStatementInput
impl GetPreparedStatementInput
Sourcepub fn statement_name(&self) -> Option<&str>
pub fn statement_name(&self) -> Option<&str>
The name of the prepared statement to retrieve.
Sourcepub fn work_group(&self) -> Option<&str>
pub fn work_group(&self) -> Option<&str>
The workgroup to which the statement to be retrieved belongs.
Sourceimpl GetPreparedStatementInput
impl GetPreparedStatementInput
Sourcepub fn builder() -> GetPreparedStatementInputBuilder
pub fn builder() -> GetPreparedStatementInputBuilder
Creates a new builder-style object to manufacture GetPreparedStatementInput.